% RDK Matlab Plot
% Reads data file (with time values), Plots data

clear
clc

% Read data file
FileName = uigetfile('*.csv','Select the RDK data file to process');
dataFile = csvread(FileName,1,0);
timeAxis = dataFile(:,1);
samples = dataFile(:,2);
startFrequency = dataFile(1,3);
stopFrequency = dataFile(1,4);
rampTime = dataFile(1,5);
sampleRate = 50e-6;
sampleFreq = 1/sampleRate;

% Raw Data Plot
figure(1)
plot(timeAxis,samples)
xlabel('Time (s)')
ylabel('Amplitude (V)')
title('Raw Data')
axis([0,max(timeAxis),-2.5,2.5])
grid on

% Beat Frequency Spectrum Plot
figure(2)
nfft = length(samples)*7;
samplesFFT = fft(samples,nfft)/nfft;
samplesFFTdBm = mag2db(abs(samplesFFT));
freqAxis = sampleFreq/2*linspace(0,1,nfft/2+1);
plot(freqAxis,samplesFFTdBm(1:nfft/2+1))
xlabel('Frequency (Hz)')
ylabel('Power (dBm)')
title('Beat Frequency Spectrum')
axis([0,max(freqAxis),min(samplesFFTdBm)-20,max(samplesFFTdBm)+20])
grid on

% Range Plot
figure(3)
rangeAxis = (3e8*((0:nfft/2)*sampleFreq/nfft))/(2*(1e9*(stopFrequency-startFrequency)/(rampTime/1000)));
plot(rangeAxis,samplesFFTdBm(1:nfft/2+1))
xlabel('Range (m)')
ylabel('Power (dBm)')
title('Range')
axis([0,max(rangeAxis),min(samplesFFTdBm)-20,max(samplesFFTdBm)+20])
grid on